@@ -249,7 +249,7 @@ def compress(tarpath, nature, dirpath_or_files):
 ADDITIONAL_ARCHIVE_FORMATS = [
     # name, extensions, function
     ("tar.Z|x", [".tar.Z", ".tar.x"], _unpack_tar),
-    ("jar", [".jar"], _unpack_jar),
+    ("jar", [".jar", ".war"], _unpack_jar),
     ("tbz2", [".tbz", "tbz2"], _unpack_tar),
     # FIXME: make this optional depending on the runtime lzip package install
     ("tar.lz", [".tar.lz"], _unpack_tar),
